==> firegpg_0.7.10.orig.tar.gz: defaults/preferences/firegpg.js <==
pref("extensions.firegpg.gmail_butons_sign", true);
pref("extensions.firegpg.gmail_butons_sign_send", true);
pref("extensions.firegpg.gmail_butons_psign", false);
pref("extensions.firegpg.gmail_butons_psign_send", false);
pref("extensions.firegpg.gmail_butons_crypt", true);
pref("extensions.firegpg.gmail_butons_crypt_send", true);
pref("extensions.firegpg.gmail_butons_sign_crypt", true);
pref("extensions.firegpg.gmail_butons_sign_crypt_send", true);
pref("extensions.firegpg.gmail_enabled", true);
pref("extensions.firegpg.default_private_key", "");
pref("extensions.firegpg.gpg_path", "");
pref("extensions.firegpg.specify_gpg_path", false);
pref("extensions.firegpg.show_website", true);
pref("extensions.firegpg.result_always_in_new_window", false);
pref("extensions.firegpg.use_gpg_agent", false);
pref("extensions.firegpg.default_memory", false);
pref("browser.preferences.animateFadeIn", false);
pref("browser.preferences.instantApply", false);
pref("extensions.firegpg.gpgauth.global.enable_gpgauth", true);
pref("extensions.firegpg.no_updates", false);
pref("extensions.firegpg.enable_gpgapi", true);
pref("extensions.firegpg.gmail_butons_use_select", false);
pref("extensions.firegpg.activate_inline", true);
pref("extensions.firegpg.gmail_disable_autosave", false);
pref("extensions.firegpg.keyserver", "pgp.mit.edu");
pref("extensions.firegpg.gmail_never_use_google_com_password", false);
pref("extensions.firegpg.gmail_use_ssl", true);
pref("extensions.firegpg.gmail_port", "465");
pref("extensions.firegpg.gmail_host", "smtp.gmail.com");
pref("extensions.firegpg.gmail_username", "");
pref("extensions.firegpg.gmail_disable_detection_of_reply_for_signs", false);
pref("extensions.firegpg.gmail_disable_auto_decryption", false);
pref("extensions.firegpg.gmail_force_from", "");
pref("extensions.firegpg.gmail_decrypt_when_reply", false);
pref("extensions.firegpg.gmail_show_user_info_for_signs", false);
pref("extensions.firegpg.gmail_keep_encrypted_mail", false);
pref("extensions.firegpg.gmail_smtp_no_auth", false);
pref("extensions.firegpg.dont_ask_to_download_key", false);
pref("extensions.firegpg.keyserver_proxy", "");
pref("extensions.firegpg.digest", "");
pref("extensions.firegpg.assisant_has_already_been_executed", false);
pref("extensions.firegpg.download_key_widhout_asking", false);
pref("extensions.firegpg.hide_the_wait_window", false);
pref("extensions.firegpg.hide_key_server_confirmation", false);
pref("extensions.firegpg.hide_key_operation_confirmation", false);
pref("extensions.firegpg.hide_download_menu", false);

==> firegpg_0.8.orig.tar.gz: defaults/preferences/firegpg.js <==
pref("extensions.firegpg.gmail_butons_sign", true);
pref("extensions.firegpg.gmail_butons_sign_send", true);
pref("extensions.firegpg.gmail_butons_psign", false);
pref("extensions.firegpg.gmail_butons_psign_send", false);
pref("extensions.firegpg.gmail_butons_crypt", true);
pref("extensions.firegpg.gmail_butons_crypt_send", true);
pref("extensions.firegpg.gmail_butons_sign_crypt", true);
pref("extensions.firegpg.gmail_butons_sign_crypt_send", true);
pref("extensions.firegpg.gmail_enabled", true);
pref("extensions.firegpg.default_private_key", "");
pref("extensions.firegpg.gpg_path", "");
pref("extensions.firegpg.specify_gpg_path", false);
pref("extensions.firegpg.show_website", true);
pref("extensions.firegpg.result_always_in_new_window", false);
pref("extensions.firegpg.use_gpg_agent", false);
pref("extensions.firegpg.default_memory", false);
pref("browser.preferences.animateFadeIn", false);
pref("browser.preferences.instantApply", false);
pref("extensions.firegpg.gpgauth.global.enable_gpgauth", false);
pref("extensions.firegpg.no_updates", false);
pref("extensions.firegpg.enable_gpgapi", true);
pref("extensions.firegpg.gmail_butons_use_select", false);
pref("extensions.firegpg.activate_inline", true);
pref("extensions.firegpg.gmail_disable_autosave", false);
pref("extensions.firegpg.keyserver", "pgp.mit.edu");
pref("extensions.firegpg.gmail_never_use_google_com_password", false);
pref("extensions.firegpg.gmail_use_ssl", true);
pref("extensions.firegpg.gmail_port", "465");
pref("extensions.firegpg.gmail_host", "smtp.gmail.com");
pref("extensions.firegpg.gmail_username", "");
pref("extensions.firegpg.gmail_disable_detection_of_reply_for_signs", false);
pref("extensions.firegpg.gmail_disable_auto_decryption", false);
pref("extensions.firegpg.gmail_force_from", "");
pref("extensions.firegpg.gmail_decrypt_when_reply", false);
pref("extensions.firegpg.gmail_show_user_info_for_signs", false);
pref("extensions.firegpg.gmail_keep_encrypted_mail", false);
pref("extensions.firegpg.gmail_smtp_no_auth", false);
pref("extensions.firegpg.dont_ask_to_download_key", false);
pref("extensions.firegpg.keyserver_proxy", "");
pref("extensions.firegpg.digest", "");
pref("extensions.firegpg.assisant_has_already_been_executed", false);
pref("extensions.firegpg.download_key_widhout_asking", false);
pref("extensions.firegpg.hide_the_wait_window", false);
pref("extensions.firegpg.hide_key_server_confirmation", false);
pref("extensions.firegpg.hide_key_operation_confirmation", false);
pref("extensions.firegpg.hide_download_menu", false);
